@@ -14,7 +14,7 @@ use log;
 pub use nacos_naming_client::error;
 
 lazy_static! {
-    static ref NACOS_CLIENT: AsyncOnce<NamingClient<HttpNamingRemote>> = AsyncOnce::new(async {
+    pub static ref NACOS_CLIENT: AsyncOnce<NamingClient<HttpNamingRemote>> = AsyncOnce::new(async {
         gen_client_from_env().await
     });
 }
